<?php

/**
 * @file
 * Admin file for the silverpop module.
 */

/**
 * Silverpop admin form.
 */
function silverpop_admin() {
  $form = array();

  $form['silverpop_tracking'] = array(
    '#type' => 'fieldset',
    '#title' => t('Silverpop Tracking'),
    '#collapsible' => TRUE,
  );

  $tracking_image_example_url = drupal_get_path('module', 'silverpop') . '/images/silverpop-web-tracking-code.png';

  $tracking_image = theme('image', array(
    'attributes' => array('style' => 'border: 1px solid #666; width: 50%;'),
    'alt' => 'Web Tracking Code example.',
    'path' => $tracking_image_example_url
  ));

  $form['silverpop_tracking']['silverpop_help'] = array(
    '#markup' => '<p>You will need to grab two values from the Silverpop web tracking
      code to add tracking to this website.</p><p>' . $tracking_image . '</p>',
  );

  $form['silverpop_tracking']['silverpop_tracked_domains'] = array(
    '#type' => 'textarea',
    '#title' => t('Tracked Domains'),
    '#default_value' => variable_get('silverpop_tracked_domains', ''),
    '#description' => 'Enter a comma-separated list of domains for Silverpop to
      track from <a target="_blank" href="https://pilot.silverpop.com/viewOrganization.do">https://pilot.silverpop.com/viewOrganization.do</a>.',
    '#rows' => 2,
  );

  $form['silverpop_tracking']['silverpop_script_src'] = array(
    '#type' => 'textarea',
    '#title' => t('Silverpop Script Source URL'),
    '#default_value' => variable_get('silverpop_script_src', ''),
    '#description' => 'Copy the source URL from the web tracking code on
      <a target="_blank" href="https://pilot.silverpop.com/viewOrganization.do">https://pilot.silverpop.com/viewOrganization.do</a>.',
    '#rows' => 2,
  );

  // Only require these settings if the webform sub-module is enabled.
  // In the future there could be additional sub-modules that require API
  // settings.
  if (module_exists('silverpop_webform')) {
    $form['silverpop_api'] = array(
      '#type' => 'fieldset',
      '#title' => t('Silverpop API Configuration'),
      '#collapsible' => TRUE,
    );

    $form['silverpop_api']['help'] = array(
      '#markup' => '<p>Add API configuration here. These settings are required
        for Webform integration.</p>',
    );

    $form['silverpop_api']['silverpop_username'] = array(
      '#type' => 'textfield',
      '#title' => t('Silverpop Engage username'),
      '#default_value' => variable_get('silverpop_username', ''),
      '#size' => 60,
      '#maxlength' => 255,
      '#description' => 'The username you use to log into the Silverpop
        administrative portal.',
      '#required' => TRUE,
    );

    $form['silverpop_api']['silverpop_password'] = array(
      '#type' => 'password',
      '#title' => t('Silverpop Engage password'),
      '#attributes' => array('value' => variable_get('silverpop_password')),
      '#default_value' => variable_get('silverpop_password', ''),
      '#size' => 60,
      '#maxlength' => 255,
      '#description' => 'The password you use to log into the Silverpop
        administrative portal.',
      '#required' => TRUE,
    );

    $form['silverpop_api']['silverpop_apihost'] = array(
      '#type' => 'textfield',
      '#title' => t('Silverpop API host'),
      '#default_value' => variable_get('silverpop_apihost', ''),
      '#size' => 60,
      '#maxlength' => 255,
      '#description' => 'Your API host is typically your engage pod number (e.g.
        Pod 5 would use api5.silverpop.com).',
      '#required' => TRUE,
    );
  }

  $form = system_settings_form($form);

  return $form;
}
